@@ -25,17 +25,20 @@ var texts = {
     svgexport: "SVG export",
     showhidelabels: "Show/hide labels",
     showhidelegend: "Show/hide legend",
+    showhideaxes: "Show/hide axes",
     stopresume: "Stop/resume",
     isolateselection: "Filter selection",
     resetfilter: "Reset filter",
     selectall: "Select all/none",
     selectneighbors: "Add neighbors",
+    egoNet: "Ego-net",
     tableselection: "Matched in table",
     reset: "Reset",
     directional: "Directional arrows",
     degree: "degree",
     none: "none",
     downloadtable: "Download table",
+    total: "Total",
     concoincidences: "Conditional coincidences",
     coincidences: "Coincidences",
     ofsomeone: "of",
