@@ -123,12 +123,40 @@ function network(Graph){
       .attr("class", "plot")
       .style({"width":width+"px","height":height+"px"});
 
-  if(options.minor){
+  if(options.note){
     panel.append("div")
-      .attr("class", "minor")
-      .html(options.minor);
+      .attr("class", "note")
+      .html(options.note);
   }
 
+// panel dragbar
+
+  var dragbar = panel.append("div")
+      .attr("class","panel-dragbar")
+      .style({"height":"5px","width":"100%","cursor":"row-resize"});
+
+  var dragOffset;
+
+  dragbar.call(d3.behavior.drag()
+    .on("dragstart", function() {
+      body.style("cursor","row-resize");
+      plot.select("svg").remove();
+      dragOffset = d3.mouse(body.node())[1]-height;
+    })
+    .on("drag", function() {
+      var value = d3.mouse(body.node())[1];
+      if(value > 200){
+        height = value-dragOffset;
+        plot.style("height",height+"px");
+      }
+    })
+    .on("dragend", function() {
+      body.style("cursor",null);
+      plot.call(drawSVG);
+      drawNet();
+    })
+  );
+
 // tables
   var tables = panel.append("div")
       .attr("class", "tables")
@@ -159,6 +187,7 @@ function network(Graph){
   selectButton(texts.tableselection,selectNodesFromTable);
   selectButton(texts.selectneighbors,selectNeighbors);
   selectButton(texts.isolateselection,isolateNodes);
+  selectButton(texts.egoNet,egoNet);
   selectButton(texts.resetfilter,deleteNoShow);
 
   tables.append("h2")
@@ -185,7 +214,7 @@ function network(Graph){
       plot.select("svg").remove();
     })
     .on("drag", function() {
-      value = d3.mouse(body.node())[0];
+      var value = d3.mouse(body.node())[0];
       if(value > 177 && value < 400){
         dragbar.style("left", value + "px")
         sidebar.style("width", (value-10) + "px")
@@ -215,6 +244,7 @@ function network(Graph){
   var applyFuncObject = {};
   applyFuncObject[texts.filter] = applyFilter;
   applyFuncObject[texts.select] = applySelection;
+  applyFuncObject[texts.egoNet] = egoNet;
   addController("nodeSelect", Graph.nodes, true, applyFuncObject);
   applyFuncObject = {};
   applyFuncObject[texts.filter] = applyFilter;
@@ -598,6 +628,7 @@ function drawSVG(sel){
 ".node > path { stroke: #000; vector-effect: non-scaling-stroke; } "+
 ".node text { stroke-width: 0.5px; font-size: 8px; fill: #444; } "+
 ".area { opacity: 0.2; stroke-width:3; } "+
+".net .axis { stroke: #aaa; opacity: 0; }"+
 ".node.selected path { stroke: yellow; stroke-width: 2; } ");
 
   var defs = svg.append("defs");
@@ -666,6 +697,7 @@ function drawSVG(sel){
   count = count+5;
   addButton(buttons,nextCount(),texts.directional,switchDirectional);
   addButton(buttons,nextCount(),texts.showhidelegend,function(){ clickHide(d3.selectAll(".scale")) });
+  addButton(buttons,nextCount(),texts.showhideaxes,function(){ clickHide(d3.selectAll(".net .axis")) });
   addButton(buttons,nextCount(),texts.showhidelabels,function(){ clickHide(d3.selectAll(".node text")) });
   count = count+5;
   addButton(buttons,nextCount(),texts.reset,function(){ location.reload(); });
@@ -675,7 +707,7 @@ function drawSVG(sel){
       .attr("transform", "translate(150,0)")
       .style("opacity",options.stopped?0:null);
 
-  displaySlider(sliders, 5, [0, -500], texts.repulsion, 'charge');
+  displaySlider(sliders, 5, [0, -1000], texts.repulsion, 'charge');
 
   displaySlider(sliders, 20, [0, 200], texts.distance, 'linkDistance');
 
@@ -686,7 +718,7 @@ function drawSVG(sel){
   }
 
   function keyflip() {
-    ctrlKey = d3.event.ctrlKey;
+    ctrlKey = d3.event.ctrlKey | d3.event.metaKey;
     shiftKey = d3.event.shiftKey;
     if(shiftKey){
       if(!saved.scale){
@@ -772,6 +804,16 @@ function drawNet(){
       .linkDistance(getLinkDistance)
       .start();
 
+  //axes
+  var axes = svg.selectAll(".axis")
+      .data([[0,1],[1,0]])
+    .enter().append("line")
+      .attr("class","axis")
+      .attr("x1",function(d){ return d[0]*width/2; })
+      .attr("y1",function(d){ return d[1]*height/2; })
+      .attr("x2",function(d){ return width/(d[0]+1); })
+      .attr("y2",function(d){ return height/(d[1]+1); })
+
   // nodes
   var node = svg.selectAll(".node")
       .data(nodes, function(d) { return d[options.nodeName]; });
@@ -780,7 +822,7 @@ function drawNet(){
   node.exit().remove();
 
   //enter nodes
-  var nodeEnter = node.enter().append("g")
+  var nodeEnter = node.enter().insert("g",".axis")
 	.attr("class", "node")
         .on("click", function(d) {
           if(ctrlKey)
@@ -1078,6 +1120,15 @@ function selectNeighbors(){
   }
 }
 
+function egoNet(){
+  if(d3.selectAll(".node.selected").empty()){
+    displayWindow(texts.alertnonodes);
+  }else{
+    selectNeighbors();
+    isolateNodes();
+  }
+}
+
 function stopResumeNet(){
   d3.selectAll(".node").each(function(d){
     if(options.stopped)
@@ -1379,7 +1430,7 @@ function showTables() {
   }
 
   var nodesData = d3.selectAll(".node.selected").data().map(cleanData),
-      linksData = Graph.links.filter(function(d){ return d.source.selected && d.target.selected; }).map(cleanData);
+      linksData = Graph.links.filter(function(d){ return !d.noShow && (d.source.selected && d.target.selected); }).map(cleanData);
   tableWrapper(nodesData,"nodes");
   tableWrapper(linksData,"links");
 
@@ -1447,16 +1498,17 @@ function selectNodesFromTable(){
 function adaptLayout(){
   var size = Math.min(width,height),
       xdim = d3.extent(Graph.nodes,function(d){ return d.x }),
-      ydim = d3.extent(Graph.nodes,function(d){ return d.y });
+      ydim = d3.extent(Graph.nodes,function(d){ return d.y }),
+      extent = d3.extent(d3.merge([xdim,ydim]));
   size = size/1.2;
 
   var x = d3.scale.linear()
     .range([(width-size)/2,(width-size)/2+size])
-    .domain(xdim);
+    .domain(extent);
 
   var y = d3.scale.linear()
     .range([(height-size)/2,(height-size)/2+size])
-    .domain(ydim);
+    .domain(extent);
 
   Graph.nodes.forEach(function(d){
     d.x = x(d.x);
@@ -1556,7 +1608,7 @@ function svg2pdf(){
 
   doc.setFontType("normal");
 
-  d3.selectAll("div.minor").each(function(){
+  d3.selectAll("div.note").each(function(){
     doc.setFontSize(18);
     doc.text(12, height-12, this.textContent);
   })
